@@ -307,10 +307,13 @@ setMethodS3("parseRaw", "RspParser", function(parser, object, what=c("comment",
 
     parts <- c(parts, part);
 
-    verbose && cat(verbose, "RSP construct(s) parsed:");
-    verbose && print(verbose, part);
-    verbose && cat(verbose, "Number of RSP constructs parsed this far: ", length(parts));
-  } # while(TRUE);
+    if (verbose) {
+      cat(verbose, "RSP construct(s) parsed:");
+      print(verbose, part);
+      cat(verbose, "Number of RSP constructs parsed this far: ", length(parts));
+    }
+  } # while(TRUE)
+
 
   # Add the rest of the buffer as text, unless empty.
   if (nchar(bfr) > 0L) {
@@ -366,8 +369,18 @@ setMethodS3("parseRaw", "RspParser", function(parser, object, what=c("comment",
 # }
 #*/#########################################################################
 setMethodS3("parse", "RspParser", function(parser, object, envir=parent.frame(), ..., until=c("*", "end", "expressions", "directives", "comments"), as=c("RspDocument", "RspString"), verbose=FALSE) {
-  # Load the package (super quietly), in case R.rsp::nnn() was called.
-  suppressPackageStartupMessages(require("R.rsp", quietly=TRUE)) || throw("Package not loaded: R.rsp");
+  ## WORKAROUND: For unknown reasons, the R.oo package needs to be
+  ## attached in order for 'R CMD build' to build the R.rsp package.
+  ## If not, the generated RSP-to-R script becomes corrupt and contains
+  ## invalid symbols, at least for '<%= ... %>' RSP constructs.
+  ## Below .requirePkg("R.oo", quietly=TRUE) is used to attach 'R.oo',
+  ## but we do it as late as possible, in order narrow down the cause.
+  ## It appears to be related to garbage collection and finalizers of
+  ## Object, which will try to attach 'R.oo' temporarily before running
+  ## finalize() on the object.  If so, it's a bug in R.oo.
+  ## /HB 2013-09-17
+  .requirePkg("R.oo", quietly=TRUE);
+
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
@@ -511,7 +524,6 @@ setMethodS3("parse", "RspParser", function(parser, object, envir=parent.frame(),
     return(returnAs(docP, as=as));
   }
 
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # (2a) Parse RSP preprocessing directive
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -538,7 +550,6 @@ setMethodS3("parse", "RspParser", function(parser, object, envir=parent.frame(),
     doc <- trimNonText(doc, verbose=less(verbose, 10));
 
     # Process all RSP preprocessing directives, i.e. <%@...%>
-
     doc <- preprocess(doc, envir=envir, ..., verbose=less(verbose, 10));
 
     # Coerce to RspString
@@ -604,12 +615,15 @@ setMethodS3("parse", "RspParser", function(parser, object, envir=parent.frame(),
   verbose && exit(verbose);
 
   returnAs(doc, as=as);
-}, protected=TRUE) # parse()
+}, createGeneric=FALSE, protected=TRUE) # parse()
 
 
 
 ##############################################################################
 # HISTORY:
+# 2013-09-17
+# o BUG FIX/WORKAROUND: parse() attaches 'R.oo' due to what appears to be
+#   a bug in how Object:s are finalize():ed when 'R.oo' is not attached.
 # 2013-03-10
 # o FIX: Now parse() trims non-text RSP constructs both before and after
 #   parsing each of them.  This fixed the problem of extraneous line breaks
