@@ -229,8 +229,9 @@ rspTangle <- function(file, ..., envir=new.env()) {
   md <- rspWeave(file, ..., preprocess=FALSE, envir=envir,
                       .engineName="R.rsp::md.rsp+knitr:pandoc");
 
-  hasPandoc <- isCapableOf(R.rsp, "pandoc");
-  if (hasPandoc) {
+  # Is Pandoc and DZSlides fully supported?
+  dzslides <- isCapableOf(R.rsp, "pandoc (>= 1.9.2)");
+  if (dzslides) {
     # Pandoc *.md to *.html
     format <- Sys.getenv("R.rsp/pandoc/args/format", "html");
     html <- knitr::pandoc(md, format=format);
@@ -248,13 +249,13 @@ rspTangle <- function(file, ..., envir=new.env()) {
       }
     }
 
-    warning("Could not find external executable 'pandoc' on this system while running 'R CMD check' on the vignettes. Will run the default post-processor instead: ", basename(md));
+    warning("Could not find external executable 'pandoc' v1.9.2 or newer on this system while running 'R CMD check' on the vignettes. Will run the default post-processor instead: ", basename(md));
 
     # If running R CMD check, silently accept that Pandoc is not
     # available.  Instead, just run it through the regular
     # Markdown to HTML postprocessor.
     html <- process(md);
-  }
+  } # if (dzslides)
 
   # Remove *.md
   file.remove(md);
@@ -263,9 +264,54 @@ rspTangle <- function(file, ..., envir=new.env()) {
 } # `.weave_md.rsp+knitr:pandoc`()
 
 
+
+.registerVignetteEngines <- function(pkgname) {
+  # Are vignette engines supported?
+  if (getRversion() < "3.0.0") return(); # Nope!
+
+  # Register vignette engines
+  vignetteEngine <- get("vignetteEngine", envir=asNamespace("tools"));
+
+  # (1) Skip engine
+  vignetteEngine("skip_Rnw", package=pkgname,
+    pattern="[.]Rnw$",
+    weave=NA
+  );
+
+  # (2) RSP engine
+  vignetteEngine("rsp", package=pkgname,
+    pattern="[.][^.]*[.]rsp$",
+    weave=rspWeave,
+    tangle=rspTangle
+  );
+
+  # (3) Markdown RSP + knitr::pandoc engine (non-offical trial version)
+  vignetteEngine("md.rsp+knitr:pandoc", package=pkgname,
+    pattern="[.]md[.]rsp$",
+    weave=`.weave_md.rsp+knitr:pandoc`,
+    tangle=rspTangle
+  );
+
+##    # "as-is" engine
+##    vignetteEngine("asis", package=pkgname, pattern="[.](pdf|html)[.]asis$",
+##                    weave=asisWeave, tangle=function(...) NULL);
+##
+##    # LaTeX engine
+##    vignetteEngine("tex", package=pkgname, pattern="[.]tex$",
+##                    weave=texWeave, tangle=function(...) NULL);
+##
+##    # Markdown engine
+##    vignetteEngine("markdown", package=pkgname, pattern="[.]md$",
+##                    weave=markdownWeave, tangle=function(...) NULL);
+} # .registerVignetteEngines()
+
+
 ###############################################################################
 # HISTORY:
+# 2013-09-19
+# o Extracted .registerVignetteEngines() from .onLoad() in zzz.R.
 # 2013-09-18
+# o Added the 'md.rsp+knitr:pandoc' engine.
 # o WORKAROUND: Added internal .getRspWeaveTangle().
 # o Now the 'md.rsp+knitr:pandoc' weaver will not give a NOTE in
 #   'R CMD check' if 'pandoc' executable is not available.
@@ -280,6 +326,7 @@ rspTangle <- function(file, ..., envir=new.env()) {
 #   the function that called rspWeave(), e.g. buildVignette() and
 #   tools::buildVignettes().
 # 2013-03-07
+# o Added the 'R.rsp::skip_Rnw' engine.
 # o CLEANUP: Dropped 'fake' processing again.
 # 2013-03-01
 # o BUG FIX: rspTangle() assumed R.utils is loaded.
